import * as prompts from "@clack/prompts";
import chalk from "chalk";
const s = prompts.spinner();
function skipSpinnerBlock(blockText) {
  s.start(chalk.gray("\u2796 " + blockText));
  s.stop(chalk.gray("\u2796 " + blockText));
}
function successSpinnerBlock(blockText) {
  s.start(chalk.green("\u2705 " + blockText));
  s.stop(chalk.green("\u2705 " + blockText));
}
async function withSpinner(callback, label, warningHint) {
  s.start(`${upperFirst(label)}...`);
  try {
    const result = await callback();
    if (result === false) {
      const extra = warningHint ? `: ${warningHint}` : "";
      s.stop(chalk.yellow(`\u26A0\uFE0F Error ${label}${extra}.`));
    } else {
      s.stop(chalk.green(`\u2705 Passed ${label}.`));
    }
    return result;
  } catch (error) {
    s.stop(chalk.red(`\u274C Error ${label}.`));
    throw new Error(`Failed ${label}`, { cause: error });
  }
}
function upperFirst(text) {
  return text[0].toUpperCase() + text.slice(1);
}
export {
  skipSpinnerBlock,
  successSpinnerBlock,
  withSpinner
};
